==> google-cloud-network-security-0.4.1.tar.gz: google-cloud-network-security-0.4.1/google/cloud/network_security_v1beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.network_security import NetworkSecurityClient
from .services.network_security import NetworkSecurityAsyncClient

from .types.authorization_policy import AuthorizationPolicy
from .types.authorization_policy import CreateAuthorizationPolicyRequest
from .types.authorization_policy import DeleteAuthorizationPolicyRequest
from .types.authorization_policy import GetAuthorizationPolicyRequest
from .types.authorization_policy import ListAuthorizationPoliciesRequest
from .types.authorization_policy import ListAuthorizationPoliciesResponse
from .types.authorization_policy import UpdateAuthorizationPolicyRequest
from .types.client_tls_policy import ClientTlsPolicy
from .types.client_tls_policy import CreateClientTlsPolicyRequest
from .types.client_tls_policy import DeleteClientTlsPolicyRequest
from .types.client_tls_policy import GetClientTlsPolicyRequest
from .types.client_tls_policy import ListClientTlsPoliciesRequest
from .types.client_tls_policy import ListClientTlsPoliciesResponse
from .types.client_tls_policy import UpdateClientTlsPolicyRequest
from .types.common import OperationMetadata
from .types.server_tls_policy import CreateServerTlsPolicyRequest
from .types.server_tls_policy import DeleteServerTlsPolicyRequest
from .types.server_tls_policy import GetServerTlsPolicyRequest
from .types.server_tls_policy import ListServerTlsPoliciesRequest
from .types.server_tls_policy import ListServerTlsPoliciesResponse
from .types.server_tls_policy import ServerTlsPolicy
from .types.server_tls_policy import UpdateServerTlsPolicyRequest
from .types.tls import CertificateProvider
from .types.tls import CertificateProviderInstance
from .types.tls import GrpcEndpoint
from .types.tls import ValidationCA

__all__ = (
    "NetworkSecurityAsyncClient",
    "AuthorizationPolicy",
    "CertificateProvider",
    "CertificateProviderInstance",
    "ClientTlsPolicy",
    "CreateAuthorizationPolicyRequest",
    "CreateClientTlsPolicyRequest",
    "CreateServerTlsPolicyRequest",
    "DeleteAuthorizationPolicyRequest",
    "DeleteClientTlsPolicyRequest",
    "DeleteServerTlsPolicyRequest",
    "GetAuthorizationPolicyRequest",
    "GetClientTlsPolicyRequest",
    "GetServerTlsPolicyRequest",
    "GrpcEndpoint",
    "ListAuthorizationPoliciesRequest",
    "ListAuthorizationPoliciesResponse",
    "ListClientTlsPoliciesRequest",
    "ListClientTlsPoliciesResponse",
    "ListServerTlsPoliciesRequest",
    "ListServerTlsPoliciesResponse",
    "NetworkSecurityClient",
    "OperationMetadata",
    "ServerTlsPolicy",
    "UpdateAuthorizationPolicyRequest",
    "UpdateClientTlsPolicyRequest",
    "UpdateServerTlsPolicyRequest",
    "ValidationCA",
)

==> google-cloud-network-security-0.7.1.tar.gz: google-cloud-network-security-0.7.1/google/cloud/network_security_v1beta1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.network_security import NetworkSecurityAsyncClient, NetworkSecurityClient
from .types.authorization_policy import (
    AuthorizationPolicy,
    CreateAuthorizationPolicyRequest,
    DeleteAuthorizationPolicyRequest,
    GetAuthorizationPolicyRequest,
    ListAuthorizationPoliciesRequest,
    ListAuthorizationPoliciesResponse,
    UpdateAuthorizationPolicyRequest,
)
from .types.client_tls_policy import (
    ClientTlsPolicy,
    CreateClientTlsPolicyRequest,
    DeleteClientTlsPolicyRequest,
    GetClientTlsPolicyRequest,
    ListClientTlsPoliciesRequest,
    ListClientTlsPoliciesResponse,
    UpdateClientTlsPolicyRequest,
)
from .types.common import OperationMetadata
from .types.server_tls_policy import (
    CreateServerTlsPolicyRequest,
    DeleteServerTlsPolicyRequest,
    GetServerTlsPolicyRequest,
    ListServerTlsPoliciesRequest,
    ListServerTlsPoliciesResponse,
    ServerTlsPolicy,
    UpdateServerTlsPolicyRequest,
)
from .types.tls import (
    CertificateProvider,
    CertificateProviderInstance,
    GrpcEndpoint,
    ValidationCA,
)

__all__ = (
    "NetworkSecurityAsyncClient",
    "AuthorizationPolicy",
    "CertificateProvider",
    "CertificateProviderInstance",
    "ClientTlsPolicy",
    "CreateAuthorizationPolicyRequest",
    "CreateClientTlsPolicyRequest",
    "CreateServerTlsPolicyRequest",
    "DeleteAuthorizationPolicyRequest",
    "DeleteClientTlsPolicyRequest",
    "DeleteServerTlsPolicyRequest",
    "GetAuthorizationPolicyRequest",
    "GetClientTlsPolicyRequest",
    "GetServerTlsPolicyRequest",
    "GrpcEndpoint",
    "ListAuthorizationPoliciesRequest",
    "ListAuthorizationPoliciesResponse",
    "ListClientTlsPoliciesRequest",
    "ListClientTlsPoliciesResponse",
    "ListServerTlsPoliciesRequest",
    "ListServerTlsPoliciesResponse",
    "NetworkSecurityClient",
    "OperationMetadata",
    "ServerTlsPolicy",
    "UpdateAuthorizationPolicyRequest",
    "UpdateClientTlsPolicyRequest",
    "UpdateServerTlsPolicyRequest",
    "ValidationCA",
)
